# Prevent RPM from stripping the binaries.
%define __strip /bin/true

Name:           ocaml-ocamlnet
Version:        3.7.3
Release:        %mkrel 3
Summary:        Network protocols for OCaml
License:        BSD
Group:          Development/OCaml
URL:            http://projects.camlcity.org/projects/ocamlnet.html
Source:         http://download.camlcity.org/download/ocamlnet-%{version}.tar.gz
BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-compiler-libs
BuildRequires:  camlp4
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-pcre-devel
BuildRequires:  ocaml-cryptgps-devel

BuildRequires:  pcre-devel
BuildRequires:  ncurses-devel
BuildRequires:  tcl-devel

%description
Ocamlnet is an ongoing effort to collect modules, classes and
functions that are useful to implement network protocols. Since
version 2.2, Ocamlnet incorporates the Equeue, RPC, and Netclient
libraries, so it now really a big player.

In detail, the following features are available:

 * netstring is about processing strings that occur in network
   context. Features: MIME encoding/decoding, Date/time parsing,
   Character encoding conversion, HTML parsing and printing, URL
   parsing and printing, OO-representation of channels, and a lot
   more.

 * netcgi1 and netcgi2 focus on portable web applications. netcgi1 is
   the older, backward-compatible version, whereas netcgi2 bases on a
   revised design, and is only partly backward-compatible. Supported
   are CGI, FastCGI, AJP (mod_jk), and SCGI.

 * rpc implements ONCRPC (alias SunRPC), the remote procedure call
   technology behind NFS and other Unix services.

 * netplex is a generic server framework. It can be used to build
   stand-alone server programs from individual components like those
   from netcgi2, nethttpd, and rpc.

 * netclient implements clients for HTTP (version 1.1, of course), FTP
   (currently partially), and Telnet.

 * equeue is an event queue used for many protocol implementations. It
   makes it possible to run several clients and/or servers in parallel
   without having to use multi-threading or multi-processing.

 * shell is about calling external commands like a Unix shell does.

 * netshm provides shared memory for IPC purposes.

 * netsys contains bindings for system functions missing in core O'Caml.

 * smtp and pop are two further client implementations for the SMTP
   and POP3 protocols.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-pcre-devel
Requires:       ocaml-cryptgps-devel
Requires:       tcl-devel

%description devel
This package contains the development files needed to build applications
using %{name}.


%package        ssl
Summary:        SSL development libraries for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
BuildRequires:  ocaml-ssl-devel
BuildRequires:  openssl-devel

Requires:       ocaml-ssl
Requires:       openssl

%description ssl
SSL development libraries for %{name}.


%package        ssl-devel
Summary:        SSL development libraries for %{name}
Group:          Development/OCaml
Requires:       %{name}-ssl = %{version}-%{release}
Requires:       openssl-devel

%description ssl-devel
This package contains the development files needed to build applications
using %{name}-ssl.


%package        gtk2
Summary:        GTK2 development libraries for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
BuildRequires:  ocaml-lablgtk2-devel
Requires:       ocaml-lablgtk2

%description gtk2
GTK2 development libraries for %{name}.


%package        gtk2-devel
Summary:        GTK2 development libraries for %{name}
Group:          Development/OCaml
Requires:       %{name}-gtk2 = %{version}-%{release}
Requires:       ocaml-lablgtk2-devel

%description gtk2-devel
This package contains the development files needed to build applications
using %{name}-gtk2.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch:      noarch

%description doc
This package contains the HTML API documentation for %{name}.


%package        nethttpd
Summary:        Ocamlnet HTTP daemon
License:        GPLv2+
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    nethttpd
Nethttpd is a web server component (HTTP server implementation). It
can be used for web applications without using an extra web server, or
for serving web services.


%package        nethttpd-devel
Summary:        Development files for %{name}-nethttpd
License:        GPLv2+
Group:          Development/OCaml
Requires:       %{name}-nethttpd = %{version}-%{release}

%description    nethttpd-devel
The %{name}-nethttpd-devel package contains libraries and signature
files for developing applications that use %{name}-nethttpd.


%prep
%setup -q -n ocamlnet-%{version}

%build
%define ocamlnet_datadir %{_datadir}/%{name}
# not an autoconf one
./configure \
  -enable-tcl \
  -equeue-tcl-libs -ltcl \
  -bindir %{_bindir} \
  -datadir %{ocamlnet_datadir} \
  -prefer-netcgi2 \
  -with-nethttpd \
  -disable-apache \
  -enable-ssl \
  -enable-pcre \
  -enable-gtk2 \
  -with-rpc-auth-dh

make all opt


%install
rm -rf %{buildroot}
install -d -m 755 %{buildroot}/%{_libdir}/ocaml
install -d -m 755 %{buildroot}/%{_libdir}/ocaml/stublibs
make install \
  OCAMLFIND_INSTFLAGS="-destdir %{buildroot}/%{_libdir}/ocaml" \
  OCAMLFIND_DESTDIR=%{buildroot}%{_libdir}/ocaml \
  DESTDIR="%{buildroot}"

# rpc-generator/dummy.mli is empty and according to Gerd Stolpmann can
# be deleted safely.  This avoids an rpmlint warning.
rm -f %{buildroot}/%{_libdir}/ocaml/rpc-generator/dummy.mli

# Strip libraries.
strip %{buildroot}/%{_libdir}/ocaml/stublibs/*.so

mv ChangeLog ChangeLog.old
iconv -f iso-8859-1 -t utf-8 < ChangeLog.old > ChangeLog

%files
%doc ChangeLog LICENSE LICENSE.GPL LICENSE.LGPL RELNOTES
%{_bindir}/*
%{_libdir}/ocaml/equeue
%{_libdir}/ocaml/equeue-tcl
%{_libdir}/ocaml/netcgi2
%{_libdir}/ocaml/netcgi2-plex
%{_libdir}/ocaml/netclient
%{_libdir}/ocaml/netplex
%{_libdir}/ocaml/netshm
%{_libdir}/ocaml/netstring
%{_libdir}/ocaml/netstring-pcre
%{_libdir}/ocaml/netsys
%{_libdir}/ocaml/netcamlbox
%{_libdir}/ocaml/netgssapi
%{_libdir}/ocaml/netmulticore
%{_libdir}/ocaml/pop
%{_libdir}/ocaml/rpc
%{_libdir}/ocaml/rpc-auth-local
%{_libdir}/ocaml/rpc-generator
%{_libdir}/ocaml/smtp
%{_libdir}/ocaml/shell
%{_libdir}/ocaml/rpc-auth-dh
%{_libdir}/ocaml/stublibs/*.so*
%exclude %{_libdir}/ocaml/stublibs/dllequeue_ssl.so*
# Adjustment for -custom compilation
#{_libdir}/ocaml/*/*.a
%exclude %{_libdir}/ocaml/*/*.cmxa
%exclude %{_libdir}/ocaml/*/*.cmx
%exclude %{_libdir}/ocaml/*/*.o
%exclude %{_libdir}/ocaml/*/*.mli
%exclude %{_libdir}/ocaml/*/*.a
%{ocamlnet_datadir}
%exclude %{_libdir}/ocaml/nethttpd-for-netcgi2
%exclude %{_libdir}/ocaml/nethttpd
%exclude %{_libdir}/ocaml/equeue-gtk2
%exclude %{_libdir}/ocaml/equeue-ssl
%exclude %{_libdir}/ocaml/rpc-ssl

%files devel
%{_libdir}/ocaml/*/*.cmxa
%{_libdir}/ocaml/*/*.cmx
%{_libdir}/ocaml/*/*.mli
%{_libdir}/ocaml/*/*.a
%{_libdir}/ocaml/netsys/netsys_oothr_mt_init.o
%exclude %{_libdir}/ocaml/nethttpd-for-netcgi2
%exclude %{_libdir}/ocaml/nethttpd
%exclude %{_libdir}/ocaml/equeue-gtk2
%exclude %{_libdir}/ocaml/equeue-ssl
%exclude %{_libdir}/ocaml/rpc-ssl

%files gtk2
%{_libdir}/ocaml/equeue-gtk2/META
%{_libdir}/ocaml/equeue-gtk2/*.cmi
%{_libdir}/ocaml/equeue-gtk2/*.cma


%files gtk2-devel
%{_libdir}/ocaml/equeue-gtk2/*.cmxa
%{_libdir}/ocaml/equeue-gtk2/*.mli
%{_libdir}/ocaml/equeue-gtk2/*.a

%files ssl
%{_libdir}/ocaml/equeue-ssl/*.cmi
%{_libdir}/ocaml/rpc-ssl/*.cma
%{_libdir}/ocaml/stublibs/dllequeue_ssl.so*

%files ssl-devel
%{_libdir}/ocaml/equeue-ssl/*.cmxa
%{_libdir}/ocaml/rpc-ssl/*.mli
%{_libdir}/ocaml/rpc-ssl/*.a

%files doc
%doc doc/html-main/
%doc examples/

%files nethttpd
%{_libdir}/ocaml/nethttpd-for-netcgi2
%{_libdir}/ocaml/nethttpd
%exclude %{_libdir}/ocaml/*/*.a
%exclude %{_libdir}/ocaml/*/*.cmxa
%exclude %{_libdir}/ocaml/*/*.mli

%files nethttpd-devel
%{_libdir}/ocaml/nethttpd/nethttpd*.a
%{_libdir}/ocaml/nethttpd/nethttpd*.cmxa
%{_libdir}/ocaml/nethttpd/nethttpd*.mli


%changelog
* Sat Oct 19 2013 umeabot <umeabot> 3.7.3-3.mga4
+ Revision: 533981
- Mageia 4 Mass Rebuild

* Sun Sep 08 2013 blue_prawn <blue_prawn> 3.7.3-2.mga4
+ Revision: 475946
- rebuild for ocaml-4.01.0

* Sat Aug 31 2013 blue_prawn <blue_prawn> 3.7.3-1.mga4
+ Revision: 473720
- updated to last version 3.7.3

* Wed Jul 31 2013 blue_prawn <blue_prawn> 3.6.6-1.mga4
+ Revision: 461515
- updated to last version 3.6.6

* Sun Apr 07 2013 malo <malo> 3.6.1-4.mga3
+ Revision: 408899
- fix requires

* Sun Jan 13 2013 umeabot <umeabot> 3.6.1-3.mga3
+ Revision: 361519
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 fwang <fwang> 3.6.1-2.mga3
+ Revision: 323826
- rebuild for new pcre

* Tue Nov 20 2012 blue_prawn <blue_prawn> 3.6.1-1.mga3
+ Revision: 319796
- update to last version 3.6.1

  + malo <malo>
    - convert ChangeLog to utf8

* Fri Oct 19 2012 malo <malo> 3.6-4.mga3
+ Revision: 308056
- rebuild for ocaml-4.0.1
- add pcre compilation option
- fix file list

* Tue Oct 02 2012 blue_prawn <blue_prawn> 3.6-3.mga3
+ Revision: 302157
- build requires ocaml-compiler-libs
- rebuild for new ocaml 4.00
- new rpm group for documentation

* Sat Sep 29 2012 blue_prawn <blue_prawn> 3.6-2.mga3
+ Revision: 300395
- new rpm group for ocaml

* Sun Aug 26 2012 blue_prawn <blue_prawn> 3.6-1.mga3
+ Revision: 284365
- corrected group for documentation
- forgot mgarepo sync
- updated to last version 3.6
- make 2 new splits to remove dependencies on gtk and ssl from the main package
- make a new split for the docs
- also provide the examples/

* Wed Feb 29 2012 blue_prawn <blue_prawn> 3.5.1-1.mga2
+ Revision: 216217
- updated to new version 3.5.1

* Tue Dec 13 2011 malo <malo> 3.4.1-1.mga2
+ Revision: 181071
- new version 3.4.1
- missing requires
- spec clean-up

* Fri Oct 07 2011 shlomif <shlomif> 3.4-2.mga2
+ Revision: 152808
- Add missing BuildRequires. Patch by Malo.
- New version 3.4 - patch by Malo.

* Sat Jul 02 2011 fwang <fwang> 3.3.3-1.mga2
+ Revision: 117452
- new version 3.3.3
- do not know why gtk22 is required
- rebuild for new tcl

* Sat Apr 30 2011 pterjan <pterjan> 2.2.9-9.mga1
+ Revision: 93946
- Bump release higher than Mandriva

* Fri Apr 08 2011 ennael <ennael> 2.2.9-8.mga1
+ Revision: 82390
- clean spec file
- imported package ocaml-ocamlnet


* Mon Sep 14 2009 Florent Monnier <blue_prawn@mandriva.org> 2.2.9-8mdv2010.0
+ Revision: 440706
- rebuild

* Wed Sep 09 2009 Florent Monnier <blue_prawn@mandriva.org> 2.2.9-7mdv2010.0
+ Revision: 436141
- added support for cryptgps
- the devel package requires ocaml-pcre-devel

* Sat Aug 22 2009 Florent Monnier <blue_prawn@mandriva.org> 2.2.9-6mdv2010.0
+ Revision: 419709
- incremented mkrel
- corrected the split

* Mon Aug 10 2009 Florent Monnier <blue_prawn@mandriva.org> 2.2.9-5mdv2010.0
+ Revision: 413869
- incremented mkrel
- corrected Requires

* Sat Jun 27 2009 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.9-4mdv2010.0
+ Revision: 390090
- rebuild

* Thu Jun 11 2009 Florent Monnier <blue_prawn@mandriva.org> 2.2.9-3mdv2010.0
+ Revision: 385257
- pcre dep updated

* Sun Jan 11 2009 Florent Monnier <blue_prawn@mandriva.org> 2.2.9-2mdv2009.1
+ Revision: 328195
- corrected group
- build/install all the modules
- update the home page
- a more detailed description
- imported a patch from fedora
  (modifications made with the help of the fedora's spec made by Richard W.M. Jones)

* Mon Dec 29 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.9-1mdv2009.1
+ Revision: 320723
- move non-devel files in main package
- site-lib hierarchy doesn't exist anymore

* Fri Aug 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.9-1mdv2009.0
+ Revision: 272354
- fix build with latest glibc
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Fri Mar 07 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.7-4mdv2008.1
+ Revision: 181156
- rebuild

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Sep 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.7-3mdv2008.0
+ Revision: 78371
- move stup libs into non-devel package

* Sat Sep 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.7-2mdv2008.0
+ Revision: 77685
- drop macro definition, now in rpm-mandriva-setup
  ship .cmi file in non-devel subpackage

* Thu Jun 07 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 2.2.7-1mdv2008.0
+ Revision: 36815
- new release: 2.2.7


* Thu Feb 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.4-5mdv2007.0
+ Revision: 124750
- devel packages requires ncurses-devel package

* Thu Feb 22 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.4-4mdv2007.1
+ Revision: 124721
- merge two package, as there is no evidence of split advantage

* Wed Feb 21 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.4-3mdv2007.1
+ Revision: 124203
- bump release?\195?\169
- split data and binaries into a non-devel package
- move data files under %%{_datadir}
- fix shm detection
- ship full html documentation
- fix file installation

* Wed Feb 21 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.4-2mdv2007.1
+ Revision: 124098
- devel package needs pcre devel package

* Tue Feb 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.4-1mdv2007.1
+ Revision: 123162
- fix build dependencies
- fix build dependencies

* Tue Feb 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.2.4-1mdv2007.1
- first mdv release

